@@ -34,27 +34,11 @@ def save_yaml(config, filename):
     return filename
 
 
-def load_app(import_path=None, django_settings_module=None):
-    # TODO add delay, test if setup is done during setup, not when handling
-    #  response
-    if django_settings_module:
-        from django.core.wsgi import get_wsgi_application
-        os.environ.setdefault("DJANGO_SETTINGS_MODULE", django_settings_module)
-        import django
-        if django.VERSION[0] <= 1 and django.VERSION[1] < 7:
-            # call django.setup only for django <1.7.0
-            # (because setup already in get_wsgi_application since that)
-            # https://github.com/django/django/commit
-            # /80d74097b4bd7186ad99b6d41d0ed90347a39b21
-            django.setup()
-        return get_wsgi_application()
-    if import_path:
-        *submodules, app_name = import_path.split(".")
-        module = import_module(".".join(submodules))
-        app = getattr(module, app_name)
-        return app
-    raise ValueError("either 'import_path' or 'django_settings_module'"
-                     "params must be provided")
+def load_app(import_path):
+    *submodules, app_name = import_path.split(".")
+    module = import_module(".".join(submodules))
+    app = getattr(module, app_name)
+    return app
 
 
 def patch_response(response):
@@ -97,11 +81,12 @@ def call_app(app, event):
 try:
     config = load_yaml(Path(Path(__file__).resolve().parent.parent,
                             DEFAULT_CONFIG_FILENAME))
-    app = load_app(config.get("entrypoint"),
-                   config.get("django_settings_module"))
+    app = load_app(config.get("entrypoint") or "")
+    os.environ.setdefault("DJANGO_SETTINGS_MODULE",
+                          config.get("django_settings_module") or "")
 except ValueError:
     # logger.warning("Looks like broken Yappa config is used")
-    pass # TODO uncomment warning when yappa in pip and it load_config is moved from this file
+    pass  # TODO uncomment warning when yappa in pip and it load_config is moved from this file
 
 
 def handle(event, context):
